multidim.Simplex — GDA Toolbox v1.0 Manual

# multidim.Simplex

class `multidim.` `Simplex`(cellcomplex, dim, index)

  This class is a convenient container to access the data in the pd DataFrame stratum[dim] of a SimplicialComplex. It is always faster to access stratum[dim].loc[index] directly.

  Parameters: | cellcomplex : `SimplicialComplex` The SimplicialComplex to which this Simplex belongs. dim : int The dimension in which this Simplex lives. index : int The abstract index of this Simplex.

  See also

  `SimplicialComplex`
    A class for abstract simpicial cell complexes.

  Notes

  A finite (abstract) simplicial complex is a finite set \(A\) together with collection \(\Delta\) of subsets of \(A\) such that if \(X \in \Delta\) and \(Y \subset X\) then \(Y \in \Delta\). [1]

  References

  [1] | (1, 2) D. Feichtner-Kozlov, Combinatorial algebraic topology. Berlin: Springer, 2008.

  Attributes: | cellcomplex : `SimplicialComplex` The `SimplicialComplex` to which this Simplex belongs. dim : int The dimension in which this Simplex lives. index : int The abstract index of this Simplex. shadow_complex : `SimplicialComplex` children : `pandas.Series`

  `Simplex.boundary` |
  return: |
  `Simplex.height` |
  return: | height (that is, filtered value) of this cell (np.float64)
  `Simplex.mass` |
  return: | mass of this cell (np.float64 or None)
  `Simplex.positive` |
  return: |
  `Simplex.representative` |
  return: |

#### Previous topic

multidim.SimplexStratum

#### Next topic

multidim.Simplex.boundary